Documentation
¶
Index ¶
- Variables
- type Context
- type Element
- type GUIKit
- func (gk *GUIKit) Broadcast(event string, payload interface{})
- func (gk *GUIKit) Get(pattern string, handler func(c *Context))
- func (gk *GUIKit) GetGlobal(key string) (interface{}, bool)
- func (gk *GUIKit) GetGlobalMap() map[string]interface{}
- func (gk *GUIKit) GetNonce(r *http.Request) string
- func (gk *GUIKit) GetSession(key string) string
- func (gk *GUIKit) HandleWebSocket(w http.ResponseWriter, r *http.Request)
- func (gk *GUIKit) Post(pattern string, handler func(c *Context))
- func (gk *GUIKit) RegisterComponent(comp LiveComponent)
- func (gk *GUIKit) Render(c *Context, viewPath string)
- func (gk *GUIKit) Run()
- func (gk *GUIKit) SecureHeaders(next http.HandlerFunc) http.HandlerFunc
- func (gk *GUIKit) SetGlobal(key string, value interface{})
- func (gk *GUIKit) SetSession(key string, value string) error
- func (gk *GUIKit) SetSessionTTL(key string, value string, ttl time.Duration) error
- type IncomingEvent
- type LiveComponent
- type Node
- type OutgoingPatch
- type Parser
- type Text
- type ThreadSafeConn
Constants ¶
This section is empty.
Variables ¶
var AppFS fs.FS
Functions ¶
This section is empty.
Types ¶
type GUIKit ¶
type GUIKit struct {
DB *ultimate_db.DB
BP *ultimate_db.BufferPool
Mux *http.ServeMux
SessionPage ultimate_db.PageID
// contains filtered or unexported fields
}
func (*GUIKit) GetGlobalMap ¶
GetGlobalMap returns a snapshot of the global state for rendering
func (*GUIKit) GetSession ¶
func (*GUIKit) HandleWebSocket ¶
func (gk *GUIKit) HandleWebSocket(w http.ResponseWriter, r *http.Request)
func (*GUIKit) RegisterComponent ¶
func (gk *GUIKit) RegisterComponent(comp LiveComponent)
func (*GUIKit) SecureHeaders ¶
func (gk *GUIKit) SecureHeaders(next http.HandlerFunc) http.HandlerFunc
type IncomingEvent ¶
type LiveComponent ¶
type OutgoingPatch ¶
type ThreadSafeConn ¶
type ThreadSafeConn struct {
// contains filtered or unexported fields
}
ThreadSafeConn wraps a websocket connection to ensure synchronized write access.
func (*ThreadSafeConn) Close ¶
func (s *ThreadSafeConn) Close() error
func (*ThreadSafeConn) WriteJSON ¶
func (s *ThreadSafeConn) WriteJSON(v interface{}) error
func (*ThreadSafeConn) WriteMessage ¶
func (s *ThreadSafeConn) WriteMessage(messageType int, data []byte) error
Click to show internal directories.
Click to hide internal directories.